pub fn canonical_spelling(ty: &Type) -> StringExpand description
canonical_type as tokens — the string form both indexes use as their key.
pub fn canonical_spelling(ty: &Type) -> Stringcanonical_type as tokens — the string form both indexes use as their key.